#! /usr/bin/env python

from unittest2 import main
main(module=None)